pub struct Replicas { /* private fields */ }Available on crate feature
replicas only.Expand description
A struct for interacting with cluster replica nodes.
All commands sent via this interface will use a replica node, if possible. The underlying connections are shared with the main client in order to maintain an up-to-date view of the system in the event that replicas change or are promoted. The cached replica routing table will be updated on the client when following cluster redirections or when any connection closes.
Implementations