pub struct RedisPool { /* private fields */ }Expand description
A cheaply cloneable round-robin client pool.
Restrictions
The following interfaces are not implemented on RedisPool:
In many cases, such as publish, callers can work around this by
adding a call to next, but in some scenarios this may not work. As a general rule, any commands
that change or depend on local connection state will not be implemented directly on RedisPool. Callers can use
clients, next, or last to operate on individual clients if needed.
Implementations
sourceimpl RedisPool
impl RedisPool
sourcepub fn from_clients(clients: Vec<RedisClient>) -> Result<Self, RedisError>
pub fn from_clients(clients: Vec<RedisClient>) -> Result<Self, RedisError>
Create a new pool from an existing set of clients.
sourcepub fn new(
config: RedisConfig,
perf: Option<PerformanceConfig>,
connection: Option<ConnectionConfig>,
policy: Option<ReconnectPolicy>,
size: usize,
) -> Result<Self, RedisError>
pub fn new( config: RedisConfig, perf: Option<PerformanceConfig>, connection: Option<ConnectionConfig>, policy: Option<ReconnectPolicy>, size: usize, ) -> Result<Self, RedisError>
Create a new pool without connecting to the server.
See the builder interface for more information.
sourcepub fn prefer_connected(&self, val: bool) -> bool
pub fn prefer_connected(&self, val: bool) -> bool
Set whether the client will use next_connected or next when routing commands among the pooled clients.
sourcepub fn clients(&self) -> &[RedisClient]
pub fn clients(&self) -> &[RedisClient]
Read the individual clients in the pool.
sourcepub fn connect_pool(&self) -> Vec<ConnectHandle>
pub fn connect_pool(&self) -> Vec<ConnectHandle>
sourcepub fn next_connected(&self) -> &RedisClient
pub fn next_connected(&self) -> &RedisClient
Read the next connected client that should run the next command.
sourcepub fn next(&self) -> &RedisClient
pub fn next(&self) -> &RedisClient
Read the client that should run the next command.
sourcepub fn last(&self) -> &RedisClient
pub fn last(&self) -> &RedisClient
Read the client that ran the last command.